***********************
Input Output Management
***********************


Standard inputs and outputs
###########################


.. |br| raw:: html

   <br />

Descriptions of the basic functions are given below.


**Function descriptions:**

.. automodule:: standardIO
   :members:
   :member-order: bysource